@@ -1,12 +1,11 @@
-# $Id: Punycode.pm 71 2007-10-12 14:55:47Z cfaerber $
+# $Id: Punycode.pm 37 2007-09-12 20:57:33Z cfaerber $
 
 package Net::IDN::Punycode;
 
 use strict;
-use utf8;
 require 5.006_000;
 
-our $VERSION = '0.99_20071012';
+our $VERSION = 0.99_20070912;
 $VERSION = eval $VERSION;
 
 require Exporter;
@@ -151,11 +150,9 @@ sub min {
 1;
 __END__
 
-=encoding utf8
-
 =head1 NAME
 
-Net::IDN::Punycode - A Bootstring encoding of Unicode for IDNA (S<RFC 3492>)
+Net::IDN::Punycode - encodes Unicode string in Punycode
 
 =head1 SYNOPSIS
 
@@ -165,37 +162,36 @@ Net::IDN::Punycode - A Bootstring encoding of Unicode for IDNA (S<RFC 3492>)
 
 =head1 DESCRIPTION
 
-This module implements the Punycode encoding. Punycode is an
-instance of a more general algorithm called Bootstring, which
-allows strings composed from a small set of "basic" code points to
-uniquely represent any string of code points drawn from a larger
-set.  Punycode is Bootstring with particular parameter values
-appropriate for IDNA.
+Net::IDN::Punycode is a module to encode/decode Unicode strings into
+Punycode, an efficient encoding of Unicode for use with IDNA.
 
-Note that this module does not do any string preparation as
-specified by I<nameprep>/I<stringprep>. It does not do add any
-prefix or suffix, either.
+This module requires Perl 5.6.0 or over to handle UTF8 flagged Unicode
+strings.
 
 =head1 FUNCTIONS
 
-The following functions are exported by default.
+This module exports following functions by default.
 
 =over 4
 
-=item encode_punycode($input)
+=item encode_punycode
 
-Decodes C<$input> with Punycode and returns the result.
+  $punycode = encode_punycode($unicode);
 
-This function will throw an exception on invalid input.
+takes Unicode string (UTF8-flagged variable) and returns Punycode
+encoding for it.
 
-=item decode_punycode($input)
+=item decode_punycode
 
-Decodes C<$input> with Punycode and returns the result.
+  $unicode = decode_punycode($punycode)
 
-This function will throw an exception on invalid input.
+takes Punycode encoding and returns original Unicode string.
 
 =back
 
+These functions throws exceptionsn on failure. You can catch 'em via
+C<eval>.
+
 =head1 AUTHOR
 
 Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt>, Claus Färber E<lt>CFAERBER@cpan.orgE<gt>
@@ -205,7 +201,6 @@ it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-S<RFC 3492> L<http://www.ietf.org/rfc/rfc3492.txt>,
-L<IETF::ACE>, L<Convert::RACE>
+L<Encode::Punycode>, http://www.ietf.org/rfc/rfc3492.txt
 
 =cut
